import sys

from PySide6.QtGui import QAction
from PySide6.QtWidgets import QSystemTrayIcon, QMenu, QMainWindow


class ExtendSystemTray(QSystemTrayIcon):

    def __init__(self, main_window: QMainWindow):
        super().__init__(parent=main_window)
        self.menu = QMenu()
        self.main_window = main_window
        self.hide_main_window_action = QAction("Hide")
        self.hide_main_window_action.triggered.connect(self.main_window.hide)
        self.menu.addAction(self.hide_main_window_action)
        self.maximized_main_window_action = QAction("Maximized")
        self.maximized_main_window_action.triggered.connect(self.main_window.showMaximized)
        self.menu.addAction(self.maximized_main_window_action)
        self.normal_main_window_action = QAction("Normal")
        self.normal_main_window_action.triggered.connect(self.main_window.showNormal)
        self.menu.addAction(self.normal_main_window_action)
        self.close_main_window_action = QAction("Close")
        self.close_main_window_action.triggered.connect(self.close_all)
        self.menu.addAction(self.close_main_window_action)
        self.setContextMenu(self.menu)

    def close_all(self):
        self.setVisible(False)
        self.main_window.close()
        sys.exit(0)




import os

from PySide6.QtWidgets import QFileDialog

from je_editor.pyside_ui.code.auto_save.auto_save_thread import SaveThread
from je_editor.utils.file.open.open_file import read_file


def choose_file_get_open_file_path(parent_qt_instance) -> None:
    """
    Open file and set code edit content
    :param parent_qt_instance: Pyside parent
    :return: None
    """
    file_path = QFileDialog().getOpenFileName(
        parent=parent_qt_instance,
        dir=os.getcwd()
    )[0]
    if file_path is not None and file_path != "":
        parent_qt_instance.current_file = file_path
        file_content = read_file(file_path)[1]
        parent_qt_instance.code_edit.setPlainText(
            file_content
            )
        if parent_qt_instance.auto_save_thread is None:
            parent_qt_instance.auto_save_thread = SaveThread(
                parent_qt_instance.current_file,
                parent_qt_instance.code_edit.toPlainText()
            )
            parent_qt_instance.auto_save_thread.start()
        if parent_qt_instance.auto_save_thread is not None:
            parent_qt_instance.auto_save_thread.file = parent_qt_instance.current_file
